@@ -1,31 +1,7 @@
 
-import json
-import pkgutil
-
-from bciavm.pipelines.components.transformers.encoders import (
-    OneHotEncoder
-)
-from bciavm.pipelines.components.transformers.preprocessing import (
-    TextFeaturizer
-)
 from bciavm.pipelines.components.transformers import Transformer
-import re
-import numpy as np
-import pandas as pd
-from pathlib import Path
 
-from bciavm.utils import (
-    classproperty,
-    get_logger,
-    import_or_raise,
-    infer_feature_types,
-    jupyter_check,
-    log_subtitle,
-    log_title,
-    safe_repr
-)
-from bciavm.utils.gen_utils import calc_nearest_area_aggregate
-import io
+import pandas as pd
 
 class PreprocessTransformer(Transformer) :
     """Transformer to Preprocessing"""
@@ -96,8 +72,7 @@ class PreprocessTransformer(Transformer) :
 
         self.lookup_table = pd.DataFrame({})
         for ct in range(1, 4):
-            #d = io.BytesIO(pkgutil.get_data('bci_avm.data.lookup_table_parquet', 'lookup_table' + str(ct) + '.parquet'))
-            d = 'https://bciavm.s3.amazonaws.com/dfPricesEpc_parquet/lookup_table'+str(ct)+'.parquet'
+            d = 'https://bciavm.s3.amazonaws.com/lookup_table_parquet/lookup_table'+str(ct)+'.parquet'
             self.lookup_table = self.lookup_table.append(pd.read_parquet(d))
 
         self.DATA_DICT = DATA_DICT
@@ -122,10 +97,10 @@ class PreprocessTransformer(Transformer) :
         if 'POSTCODE' not in lookup_table.columns:
             self.lookup_table = pd.DataFrame({})
             for ct in range(1, 4):
-                d = io.BytesIO(
-                    pkgutil.get_data('bci_avm.data.lookup_table_parquet', 'lookup_table' + str(ct) + '.parquet'))
+                d = 'https://bciavm.s3.amazonaws.com/lookup_table_parquet/lookup_table' + str(ct) + '.parquet'
                 self.lookup_table = self.lookup_table.append(pd.read_parquet(d))
-            lookup_table = self.lookup_table
+
+        lookup_table = self.lookup_table
 
         if 'POSTCODE' not in request_data.columns:
             for col in request_data.columns:
